<template>
  <div>
    <el-dialog
      title="施工班组"
      :visible.sync="dialogVisible"
      :open="open"
      width="900px"
      appendToBody
      :close-on-click-modal="false"
      top="5vh"
      @close="closeDialog"
      v-if="dialogVisible"
      append-to-body
    >
      <el-container>
        <el-main style="padding: 10px; height: 400px">
          <ht-table
            @load="loadData"
            :data="data"
            :selectable="false"
            :highlightCurrentRow="true"
            :page-result="pageBean"
            :nopagination='true'
            quick-search-props="code,name"
            ref="htTable"
            :show-export="false"
            :show-custom-column="false"
            @select="select"
            @select-all="selectAll"
            :default-querys="[{property: 'handlingSituation', value: 0}]"
          >
            <template v-slot:toolbar>
              <el-tooltip
                effect="dark"
                content="鼠标覆盖一条数据点击进行选取"
                placement="right"
              >
                <el-tag type="info">
                  <span class="el-icon-question"> 提示 </span>
                </el-tag>
              </el-tooltip>
            </template>
            <template>
              <el-table-column
                type="selection"
                align="center"
                width="45"
                v-if="!this.single"
              ></el-table-column>
              <el-table-column align="center" width="50" v-if="this.single">
                <template slot-scope="scope">
                  <el-radio
                    v-model="selectedId"
                    :label="scope.row.id"
                  ></el-radio>
                </template>
              </el-table-column>
              <ht-table-column
                prop="code"
                label="组织编码"
                :sortable="true"
                :show-overflow-tooltip="true"
              >
              </ht-table-column>
              <ht-table-column
                prop="name"
                label="组织名称"
                :sortable="true"
                :show-overflow-tooltip="true"
              >
              </ht-table-column>
              <!-- <ht-table-column
                prop="nowNum"
                label="组织现编用户数量"
                :sortable="true"
                :show-overflow-tooltip="true"
              >
              </ht-table-column>
              <ht-table-column
                prop="parentOrgName"
                label="上级组织名称"
                :show-overflow-tooltip="true"
              >
              </ht-table-column> -->

              <ht-table-column
                prop="pathName"
                label="组织路径名"
                :show-overflow-tooltip="true"
              >
              </ht-table-column>
            </template>
          </ht-table>
        </el-main>
      </el-container>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="handleOK" size="medium"
          >确 定</el-button
        >
        <el-button @click="closeDialog" size="medium">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import req from '@/request.js'
import basicData from '@/api/basicData.js'
import utils from '@/hotent-ui-util.js'
export default {
  components: {},
  props: {
    single: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      queryId: '', //养护单位id，查询参数
      dialogVisible: false,
      pageBean: {
        page: 1,
        pageSize: 20,
        total: 0
      },
      data: [],
      activeRow: {},
      selectedId: null
    }
  },
  methods: {
    select(selection,row) {
      this.activeRow = selection
      // this.selectedId = row.id
      // console.log(selection, 'eeeeee')
    },
    selectAll(selection) {
      this.activeRow = selection
    },
    open(id) {
      this.queryId = id
      this.dialogVisible = true
    },
    handleOK() {
      let selectRow = utils.deepClone(this.activeRow)
      console.log(selectRow)
      if (selectRow == {}) {
        console.log('空的')
      } else {
        this.$emit('select', selectRow)
      }
      // this.selectedId = null
      this.dialogVisible = false
      this.activeRow = {}
    },
    loadData(param, cb) {
      this.exportQuery = param
      this.$http
        .get('${form}/api/org/v1/orgs/getOrgsByparentId?parentId=' + this.queryId)
        .then(
          resp => {
            // console.log(resp, 'dddddddddd')
            let res = resp.data
            // let arr = []
            // res.filter(item => {
            //   if (item.temporary == 0) {
            //     arr = arr.concat(item)
            //   }
            // })
            this.data = res
            // this.pageBean = {
            //   page: res.page,
            //   pageSize: res.pageSize,
            //   total: res.total
            // }
          },
          error => {
            reject(error)
          }
        )
        .finally(() => {
          if (cb) {
            cb()
          }
        })
    },
    closeDialog() {
      this.dialogVisible = false
      this.activeRow = {}
    }
  }
}
</script>

<style lang="scss" scoped>
>>> .el-dialog__body {
  padding-bottom: 0px !important;
}
/deep/ .el-dialog__header {
  border-right: 1px solid #103c5d;
}
</style>
